<?php
/**
 * Plugin Name: Promenade Easing Slider
 * Plugin URI: https://audiotheme.com/view/promenade/
 * Description: Replace the homepage hero image with an Easing Slider.
 * Version: 1.0.1
 * Author: AudioTheme
 * Author URI: https://audiotheme.com/
 * License: GPL-2.0+
 * License URI: http://www.gnu.org/licenses/gpl-2.0.html
 */

// Exit if accessed directly.
defined( 'ABSPATH' ) || exit;

function promenade_easing_slider_setup() {
	if ( ! class_exists( 'Easing_Slider' ) ) {
		return;
	}

	add_action( 'promenade_register_template_parts', 'promenade_easing_slider_register_template_parts' );
	add_action( 'customize_register', 'promenade_easing_slider_customize_register' );
}
add_action( 'plugins_loaded', 'promenade_easing_slider_setup' );

/**
 * Replace the front page hero image with a slider.
 *
 * @since 1.0.0
 */
function promenade_easing_slider_register_template_parts() {
	$slider_id = get_theme_mod( 'front_page_easing_slider' );

	if ( ! is_front_page() || empty( $slider_id ) ) {
		return;
	}

	remove_action( 'promenade_content_top', 'promenade_hero_image', 15 );
	add_action( 'promenade_content_top', 'promenade_easing_slider_front_page_hero_slider', 15 );
}

/**
 * Display the front page hero slider.
 *
 * @since 1.0.0
 */
function promenade_easing_slider_front_page_hero_slider() {
	easingslider ( get_theme_mod( 'front_page_easing_slider' ) );
}

/**
 * Register Customizer support for the front page slider.
 *
 * @since 1.0.0
 *
 * @param WP_Customize_Manager $wp_customize Customizer object.
 */
function promenade_easing_slider_customize_register( $wp_customize ) {
	$sliders = ES_Slider::all();

	$wp_customize->add_setting( 'front_page_easing_slider', array(
		'sanitize_callback' => 'absint',
	) );

	$wp_customize->add_control( 'promenade_front_page_easing_slider', array(
		'type'     => 'select',
		'label'    => __( 'Front Page Slider', 'promenade' ),
		'section'  => 'theme_options',
		'settings' => 'front_page_easing_slider',
		'choices'  => array( '' => '' ) + wp_list_pluck( $sliders, 'post_title', 'ID' ),
		'priority' => 30,
	) );
}
